@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -8,8 +8,8 @@
 #include "kmkernel.h"
 
 #include <Akonadi/ChangeRecorder>
-#include <Akonadi/Contact/ContactsTreeModel>
-#include <Akonadi/Contact/EmailAddressSelectionWidget>
+#include <Akonadi/ContactsTreeModel>
+#include <Akonadi/EmailAddressSelectionWidget>
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/Session>
@@ -106,7 +106,7 @@ void AddEmailToExistingContactDialog::writeConfig()
 Akonadi::Item AddEmailToExistingContactDialog::selectedContact() const
 {
     Akonadi::Item item;
-    Akonadi::EmailAddressSelection::List lst = mEmailSelectionWidget->selectedAddresses();
+    const Akonadi::EmailAddressSelection::List lst = mEmailSelectionWidget->selectedAddresses();
     if (!lst.isEmpty()) {
         item = lst.at(0).item();
     }
