@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,6 +27,14 @@ QString AccountInfoSource::description() const
     return i18n("Number and type of accounts configured in KMail (receiver and sender).");
 }
 
+void AccountInfoSource::updateAccountInfo(const QString &resourceName, int numberOfResource, QVariantList &l)
+{
+    QVariantMap m;
+    m.insert(QStringLiteral("name"), resourceName);
+    m.insert(QStringLiteral("number"), numberOfResource);
+    l.push_back(m);
+}
+
 QVariant AccountInfoSource::data()
 {
     const Akonadi::AgentInstance::List lst = MailCommon::Util::agentInstances();
@@ -51,44 +59,25 @@ QVariant AccountInfoSource::data()
         } else if (identifier.startsWith(QLatin1String("akonadi_mbox_resource"))) {
             numberOfMbox++;
         }
-        // TODO add more
     }
     QVariantList l;
     if (numberOfImap > 0) {
-        QVariantMap m;
-        m.insert(QStringLiteral("name"), QStringLiteral("imap"));
-        m.insert(QStringLiteral("number"), numberOfImap);
-        l.push_back(m);
+        updateAccountInfo(QStringLiteral("imap"), numberOfImap, l);
     }
     if (numberOfPop3 > 0) {
-        QVariantMap m;
-        m.insert(QStringLiteral("name"), QStringLiteral("pop3"));
-        m.insert(QStringLiteral("number"), numberOfPop3);
-        l.push_back(m);
+        updateAccountInfo(QStringLiteral("pop3"), numberOfPop3, l);
     }
     if (numberOfKolab > 0) {
-        QVariantMap m;
-        m.insert(QStringLiteral("name"), QStringLiteral("kolab"));
-        m.insert(QStringLiteral("number"), numberOfKolab);
-        l.push_back(m);
+        updateAccountInfo(QStringLiteral("kolab"), numberOfKolab, l);
     }
     if (numberOfEws > 0) {
-        QVariantMap m;
-        m.insert(QStringLiteral("name"), QStringLiteral("ews"));
-        m.insert(QStringLiteral("number"), numberOfEws);
-        l.push_back(m);
+        updateAccountInfo(QStringLiteral("ews"), numberOfEws, l);
     }
     if (numberOfMaildir > 0) {
-        QVariantMap m;
-        m.insert(QStringLiteral("name"), QStringLiteral("maildir"));
-        m.insert(QStringLiteral("number"), numberOfMaildir);
-        l.push_back(m);
+        updateAccountInfo(QStringLiteral("maildir"), numberOfMaildir, l);
     }
     if (numberOfMbox > 0) {
-        QVariantMap m;
-        m.insert(QStringLiteral("name"), QStringLiteral("mbox"));
-        m.insert(QStringLiteral("number"), numberOfMbox);
-        l.push_back(m);
+        updateAccountInfo(QStringLiteral("mbox"), numberOfMbox, l);
     }
 
     // Mail Transport
